# [pnplabs.io](https://pnplabs.io) client

## Command aliases are dead. Create and share your commands online today.

Go to [pnplabs.io](https://pnplabs.io) and try out our platform!

### 🔭 We're currently working on:
- Cross-platform support for adding a directory to the OS PATH env var.
- Cross-platform support for adding Python scripts to run on startup / user login.

### 📫 How to reach us: ...
- Email us at anything@pnplabs.io
- Live chat on [pnplabs.io](https://pnplabs.io)

## About us
### Our STORY
Obsessed with making dev teamwork as seamless and frictionless as possible, we've built an innovative platform to enhance team sync and collaboration.
### Our VISION
When it comes to technical communication, we believe in seamless team synchronization. We reduce technical noise by making information visible and auditable to all team members.
### Our PHILOSOPHY
Built with great respect to developers precious time, our software requires zero attention, zero maintenance, zero learning curve.


<!--
**pnplabs/pnplabs** is a ✨ _special_ ✨ repository because its `README.md` (this file) appears on your GitHub profile.

Here are some ideas to get you started:

- 🔭 I’m currently working on ...
- 🌱 I’m currently learning ...
- 👯 I’m looking to collaborate on ...
- 🤔 I’m looking for help with ...
- 💬 Ask me about ...
- 📫 How to reach me: ...
- 😄 Pronouns: ...
- ⚡ Fun fact: ...
-->
